SET GLOBAL max_allowed_packet=104857600;

-- 
-- FUNCTION 
-- 

DELIMITER $$

CREATE DEFINER=`root`@`localhost` FUNCTION `GetAutoID`(t_name VARCHAR(50)) RETURNS int(11)
BEGIN
	DECLARE autoid INT;
	SELECT AUTO_INCREMENT into autoid FROM information_schema.TABLES
						WHERE table_name=t_name AND table_schema=schema();
	RETURN (autoid);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetAvailableScratchCard`(p_from varchar(40), p_to varchar(40)) RETURNS int(11)
BEGIN
	DECLARE count_total int(11);	
	select count(*) as total into count_total  from scratch_card_detail 
		where serial_no BETWEEN p_from AND p_to;
	return (count_total);
    END$$ 

CREATE DEFINER=`root`@`localhost` FUNCTION `GetBatchDistributedCount`(p_card_info_id int(11)) RETURNS int(11)
BEGIN
	DECLARE total int(11);
	select count(*) into total from scratch_card_detail where scratch_card_detail.card_info_id = p_card_info_id
	AND (scratch_card_detail.group_id > 0 OR scratch_card_detail.lco_id  > 0);
	return total;
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetDistributorName`(`id` INT(11)) RETURNS varchar(50) CHARSET latin1
BEGIN
	DECLARE name varchar(100);
	SELECT distributor_name into name FROM distributors
		WHERE distributors.id = id;
	RETURN (name);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetExpiredAddOnSubscriptionCount`(`user_id` INT(11)) RETURNS int(11)
BEGIN
	DECLARE total_count int;
	begin 
		SELECT count(user_addon_packages.id) as expired_packages into total_count
			FROM user_addon_packages WHERE package_expire_date < NOW()
			AND user_addon_packages.user_id = user_id 
			GROUP BY user_addon_packages.user_id;
	end;
	RETURN (total_count);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetExpiredSubscriptionCount`(`user_id` INT(11)) RETURNS int(11)
BEGIN
	DECLARE total_count int;
	begin 
		SELECT count(user_packages.id) as expired_packages into total_count
			FROM user_packages WHERE package_expire_date < NOW()
			AND user_packages.user_id = user_id 
			GROUP BY user_packages.user_id;
	end;
	RETURN (total_count);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetGroupLCOCount`(`group_id` INT(11)) RETURNS int(11)
BEGIN
	DECLARE result int(11);
	select count(id) as total into result from lco_groups WHERE lco_groups.group_id = group_id;
	return (result);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetGroupName`(`user_id` INT(11)) RETURNS varchar(50) CHARSET latin1
BEGIN
	DECLARE name varchar(100);
	SELECT group_name into name FROM group_profiles
		JOIN users ON users.profile_id = group_profiles.id
		WHERE users.id = user_id;
	RETURN (name);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetLCOName`(`user_id` INT(11)) RETURNS varchar(50) CHARSET latin1
BEGIN
	DECLARE name varchar(100);
	SELECT lco_name into name FROM lco_profiles
		JOIN users ON users.profile_id = lco_profiles.id
		WHERE users.id = user_id;
	RETURN (name);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetMessageSign`(`user_id` INT(11)) RETURNS varchar(50) CHARSET latin1
BEGIN
	DECLARE msg_sign varchar(100);
	SELECT message_sign into msg_sign FROM lco_profiles
		JOIN users ON users.profile_id = lco_profiles.id
		WHERE users.id = user_id;
	RETURN (msg_sign);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetMSOName`(`user_id` INT(11)) RETURNS varchar(50) CHARSET latin1
BEGIN
	DECLARE name varchar(100);
	SELECT mso_name into name FROM mso_profiles
		JOIN users ON users.profile_id = mso_profiles.id
		WHERE users.id = user_id;
	RETURN (name);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetOperatorName`(`parent_id` INT(11)) RETURNS varchar(255) CHARSET latin1
BEGIN
	
	DECLARE name varchar(255);
	IF parent_id = 1 THEN SET name = GetMSOName(parent_id);
        ELSE SET name = GetLCOName(parent_id);
	END IF;
	return name;
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetPackageProgramsCount`(`package_id` INT(11)) RETURNS int(11)
BEGIN
	DECLARE result int(11);
	select count(id) as programs into result from package_programs WHERE package_programs.package_id = package_id;
	return (result);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetRegionL1Name`(`p_id` INT(11)) RETURNS varchar(50) CHARSET latin1
BEGIN
	DECLARE region_name varchar(50);
	begin 
		SELECT region_l1_name into region_name
			FROM region_level_1 WHERE id = p_id;
			
	end;
	RETURN (region_name);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetRegionL2Name`(`p_id` INT(11)) RETURNS varchar(50) CHARSET latin1
BEGIN
	DECLARE region_name varchar(50);
	begin 
		SELECT region_l2_name into region_name
			FROM region_level_2 WHERE id = p_id;
			
	end;
	RETURN (region_name);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetRegionL3Name`(`p_id` INT(11)) RETURNS varchar(50) CHARSET latin1
BEGIN
	DECLARE region_name varchar(50);
	begin 
		SELECT region_l3_name into region_name
			FROM region_level_3 WHERE id = p_id;
			
	end;
	RETURN (region_name);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetRegionL4Name`(`p_id` INT(11)) RETURNS varchar(50) CHARSET latin1
BEGIN
	DECLARE region_name varchar(50);
	begin 
		SELECT region_l4_name into region_name
			FROM region_level_4 WHERE id = p_id;
			
	end;
	RETURN (region_name);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetSubscriberAddonPackageCount`(`user_id` INT(11)) RETURNS int(11)
BEGIN
	
	DECLARE total_packages float;
	begin
		SELECT count(user_addon_packages.id)as t into total_packages
		FROM user_addon_packages 
		WHERE user_addon_packages.user_id = user_id 
		GROUP BY user_addon_packages.user_id;
	end;
	RETURN (total_packages);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetSubscriberBal`(`p_id` INT(11)) RETURNS float
BEGIN
	begin
	DECLARE v_bal INT;
	begin
	SELECT balance into  v_bal FROM billing_subscriber_transactions 
	WHERE subscriber_id = p_id ORDER BY id DESC LIMIT 1;
	end;
	RETURN (v_bal);
	end;
END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetSubscriberName`(`user_id` INT(11)) RETURNS varchar(50) CHARSET latin1
BEGIN
	DECLARE name varchar(100);
	SELECT subscriber_name into name FROM subscriber_profiles
		JOIN users ON users.profile_id = subscriber_profiles.id
		WHERE users.id = user_id;
	RETURN (name);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetSubscriberPackagesCount`(`user_id` INT(11)) RETURNS int(11)
BEGIN
	
	DECLARE total_packages float;
	begin
		SELECT count(user_packages.id)as t into total_packages
		FROM user_packages 
		WHERE user_packages.user_id = user_id 
		GROUP BY user_packages.user_id;
	end;
	RETURN (total_packages);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetSubscriberPayable`(`user_id` INT(11)) RETURNS float
BEGIN
	
	DECLARE amount float;
	begin
		SELECT sum(price) into amount
		FROM user_packages
		JOIN packages ON packages.id = user_packages.package_id
		WHERE user_packages.user_id = user_id
		GROUP BY user_id;
	end;
	RETURN (amount);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetTotalSTB`(`user_id` INT(11)) RETURNS int(11)
BEGIN
	
	DECLARE total_stb float;
	begin
		SELECT count(subscriber_stb_smartcards.id)as t into total_stb
		FROM subscriber_stb_smartcards 
		WHERE subscriber_stb_smartcards.subscriber_id = user_id 
		GROUP BY subscriber_stb_smartcards.subscriber_id;
	end;
	IF total_stb >0 THEN
		RETURN (total_stb);
	ELSE 
		RETURN (0);
	END IF;
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetTotalUnAssignedPrograms`() RETURNS int(11)
BEGIN
	DECLARE total_unassigned_programs int;
	SELECT count(id) as unassigned_programs into total_unassigned_programs FROM ( SELECT `programs`.`id`, `programs`.`program_name`, `programs`.`lcn`, `programs`.`program_service_id`,count(package_programs.program_id) as assigned
	FROM `programs`
	LEFT JOIN `package_programs` ON `programs`.`id` = `package_programs`.`program_id`
	GROUP BY id
	ORDER BY id ASC) as a
	WHERE a.assigned = 0;
	RETURN (total_unassigned_programs);
    END$$ 

CREATE DEFINER=`root`@`localhost` FUNCTION `GetUsedScratchCard`(p_from varchar(40), p_to varchar(40)) RETURNS int(11)
BEGIN
	DECLARE count_used int(11);	
	select sum(is_used) as used into count_used  from scratch_card_detail 
		where serial_no BETWEEN p_from AND p_to;
	return (count_used);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetUserName`(`user_id` INT(11)) RETURNS varchar(50) CHARSET latin1
BEGIN
	DECLARE name varchar(100);
	SELECT username into name FROM users
		
		WHERE users.id = user_id;
	RETURN (name);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetUserPackageAssignTypeName`(`pid` INT) RETURNS varchar(100) CHARSET latin1
BEGIN
	Declare type_name varchar(100);
	SELECT type into type_name from user_package_assign_types where id = pid;	
	return type_name;
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `GetUserRole`(`user_id` INT(11)) RETURNS varchar(50) CHARSET latin1
BEGIN
	DECLARE name varchar(100);
	SELECT lower(role_name) into name FROM roles
		JOIN users ON users.role_id = roles.id
		WHERE users.id = user_id;
	RETURN (name);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `get_level_1_autoID`(`p_client_id` BIGINT(20)) RETURNS int(11)
BEGIN
	DECLARE v_auto_id int(11);  
	DECLARE not_found  	int(11);
					BEGIN
					declare CONTINUE HANDLER FOR NOT FOUND SET not_found=1;
					Begin
						select auto_increment into v_auto_id
						from information_schema.tables
						where table_name='region_level_1'; 
						If not_found =1 then
						set v_auto_id =0;
						End If;
					End;
					END;
     RETURN (v_auto_id);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `HasCreatePermission`(`r_id` INT(11), `mo_id` INT(11), `me_id` INT(11)) RETURNS int(11)
BEGIN
	DECLARE result int(11);
	DECLARE s int(11);
	SELECT plaas_role_menu_privileges.create into result FROM plaas_role_menu_privileges
		WHERE role_id = r_id AND module_id = mo_id AND menu_id = me_id;
	IF result >= 0 THEN
		SET s=result;
	ELSE 
		SET s=0;
	END IF;
	RETURN (s);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `HasDeletePermission`(`r_id` INT(11), `mo_id` INT(11), `me_id` INT(11)) RETURNS int(11)
BEGIN
	DECLARE result int(11);
	DECLARE s int(11);
	SELECT plaas_role_menu_privileges.delete into result FROM plaas_role_menu_privileges
		WHERE role_id = r_id AND module_id = mo_id AND menu_id = me_id;
	IF result >= 0 THEN
		SET s=result;
	ELSE 
		SET s=0;
	END IF;
	RETURN (s);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `HasEditPermission`(`r_id` INT(11), `mo_id` INT(11), `me_id` INT(11)) RETURNS int(11)
BEGIN
	DECLARE result int(11);
	DECLARE s int(11);
	SELECT plaas_role_menu_privileges.edit into result FROM plaas_role_menu_privileges
		WHERE role_id = r_id AND module_id = mo_id AND menu_id = me_id;
	IF result >= 0 THEN
		SET s=result;
	ELSE 
		SET s=0;
	END IF;
	RETURN (s);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `HasLCOBusinessRegion`(`r1` VARCHAR(11), `r2` VARCHAR(11), `r3` VARCHAR(11), `r4` VARCHAR(11)) RETURNS varchar(11) CHARSET latin1
BEGIN
	DECLARE rs varchar(11);
	
		IF ((r1 ='0' || r1 is null) AND (r2 = '0'||r2 is null) AND (r3 ='0'||r3 is null) AND (r4 ='0'|| r4 is null))  THEN
		SET rs = '0';
		ELSE 
			SET rs = '1';
		END IF;
			
	
	RETURN (rs);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `HasMenuPermission`(`r_id` INT(11), `mo_id` INT(11), `me_id` INT(11)) RETURNS int(11)
BEGIN
	DECLARE result int(11);
	DECLARE s int(11);
	SELECT plaas_role_menu_privileges.view into result FROM plaas_role_menu_privileges
		WHERE role_id = r_id AND module_id = mo_id AND menu_id = me_id;
	IF result >= 0 THEN
		SET s=result;
	ELSE 
		SET s=0;
	END IF;
	RETURN (s);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `HasPermissionToRoute`(`r_id` INT(11), `mo_id` INT(11), `route` VARCHAR(100)) RETURNS int(11)
BEGIN
	DECLARE result int(11);
	DECLARE s int(11);
	SELECT plaas_role_menu_privileges.view into result FROM plaas_role_menu_privileges
		JOIN plaas_menus ON plaas_menus.id = plaas_role_menu_privileges.menu_id
		WHERE role_id = r_id AND plaas_role_menu_privileges.module_id = mo_id AND plaas_menus.route = route;
	IF result >= 0 THEN
		SET s=result;
	ELSE 
		SET s=0;
	END IF;
	RETURN (s);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `HasViewPermission`(`r_id` INT(11), `mo_id` INT(11), `me_id` INT(11)) RETURNS int(11)
BEGIN
	DECLARE result int(11);
	DECLARE s int(11);
	SELECT plaas_role_menu_privileges.view into result FROM plaas_role_menu_privileges
		WHERE role_id = r_id AND module_id = mo_id AND menu_id = me_id;
	IF result >= 0 THEN
		SET s=result;
	ELSE 
		SET s=0;
	END IF;
	RETURN (s);
    END$$ 

CREATE DEFINER=`root`@`%` FUNCTION `IsRoleAssigned`(`pid` INT(11)) RETURNS int(11)
BEGIN
	DECLARE assigned int(11);
	SELECT count(*) as total into assigned FROM users WHERE role_id = pid; 
	RETURN (assigned);
    END$$ 

DELIMITER ; 

-- 
-- Tables 
-- 

-- Structure for Table `areas` 

DROP TABLE IF EXISTS `areas`; 

CREATE TABLE `areas` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `area_name` varchar(100) NOT NULL,
  `area_code` varchar(10) DEFAULT NULL,
  `country_id` int(11) DEFAULT NULL,
  `division_id` int(11) DEFAULT NULL,
  `district_id` int(11) NOT NULL,
  `lat` varchar(255) DEFAULT NULL,
  `lon` varchar(255) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `FK_areas` (`country_id`)
) ENGINE=InnoDB AUTO_INCREMENT=49 DEFAULT CHARSET=utf8;

-- Structure for Table `back_colors` 

DROP TABLE IF EXISTS `back_colors`; 

CREATE TABLE `back_colors` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) DEFAULT NULL,
  `value` varchar(100) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=12 DEFAULT CHARSET=latin1;

-- Structure for Table `bank_accounts` 

DROP TABLE IF EXISTS `bank_accounts`; 

CREATE TABLE `bank_accounts` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `bank_name` varchar(100) DEFAULT NULL,
  `address` text,
  `account_name` varchar(100) DEFAULT NULL,
  `account_no` varchar(100) DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT '1',
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  `token` varchar(40) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `bank_accounts_assign` 

DROP TABLE IF EXISTS `bank_accounts_assign`; 

CREATE TABLE `bank_accounts_assign` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `bank_account_id` int(11) DEFAULT NULL,
  `lco_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT '1',
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `billing_addresses` 

DROP TABLE IF EXISTS `billing_addresses`; 

CREATE TABLE `billing_addresses` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `user_id` int(11) DEFAULT NULL,
  `is_same_as_profile` tinyint(1) DEFAULT '0',
  `name` varchar(255) DEFAULT NULL,
  `email` varchar(255) DEFAULT NULL,
  `address1` text,
  `address2` text,
  `country_id` int(11) DEFAULT NULL,
  `division_id` int(11) DEFAULT NULL,
  `district_id` int(11) DEFAULT NULL,
  `area_id` int(11) DEFAULT NULL,
  `sub_area_id` int(11) DEFAULT NULL,
  `road_id` int(11) DEFAULT NULL,
  `contact` varchar(11) DEFAULT NULL,
  `is_same_as_contact` tinyint(1) DEFAULT '0',
  `billing_contact` varchar(11) DEFAULT NULL,
  `token` varchar(40) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fk_profiles_areas1_idx` (`area_id`),
  KEY `fk_profiles_districts1_idx` (`district_id`),
  KEY `fk_profiles_divisions1_idx` (`division_id`),
  KEY `fk_profiles_countries1_idx` (`country_id`)
) ENGINE=InnoDB AUTO_INCREMENT=7422 DEFAULT CHARSET=utf8;

-- Structure for Table `billing_bank_card_list` 

DROP TABLE IF EXISTS `billing_bank_card_list`; 

CREATE TABLE `billing_bank_card_list` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `bank_card_name` varchar(100) DEFAULT NULL,
  `bank_card_type` varchar(100) DEFAULT NULL,
  `issuer_bank` varchar(100) DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `billing_bank_list` 

DROP TABLE IF EXISTS `billing_bank_list`; 

CREATE TABLE `billing_bank_list` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `bank_name` varchar(200) DEFAULT NULL,
  `Address` varchar(260) DEFAULT NULL,
  `branch` varchar(100) DEFAULT NULL,
  `contact_person` varchar(200) DEFAULT NULL,
  `contact_number` varchar(100) DEFAULT NULL COMMENT 'contact Number could be comma seperated',
  `is_active` tinyint(1) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `billing_bank_transactions` 

DROP TABLE IF EXISTS `billing_bank_transactions`; 

CREATE TABLE `billing_bank_transactions` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `bank_account_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `pairing_id` int(11) DEFAULT NULL,
  `payment_type_id` int(11) DEFAULT NULL,
  `subscriber_transaction_id` int(11) DEFAULT NULL,
  `amount` decimal(10,0) DEFAULT NULL,
  `check_no` varchar(30) DEFAULT NULL,
  `transaction_id` varchar(100) DEFAULT NULL,
  `depositor_name` varchar(100) DEFAULT NULL,
  `depositor_phone` varchar(20) DEFAULT NULL,
  `deposit_date` datetime DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `billing_bkash_transactions` 

DROP TABLE IF EXISTS `billing_bkash_transactions`; 

CREATE TABLE `billing_bkash_transactions` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `pairing_id` int(11) DEFAULT NULL,
  `amount` varchar(100) DEFAULT NULL,
  `bkash_phone` varchar(11) DEFAULT NULL,
  `bkash_transaction_id` varchar(100) DEFAULT NULL,
  `subscriber_transaction_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `billing_cash_transection` 

DROP TABLE IF EXISTS `billing_cash_transection`; 

CREATE TABLE `billing_cash_transection` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `subscriber_transection_id` int(11) DEFAULT NULL,
  `lco_id` int(11) DEFAULT NULL,
  `collector_id` varchar(11) DEFAULT NULL,
  `receipt_number` varchar(100) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `NewIndex1` (`subscriber_transection_id`,`lco_id`,`collector_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `billing_lco_collector` 

DROP TABLE IF EXISTS `billing_lco_collector`; 

CREATE TABLE `billing_lco_collector` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) DEFAULT NULL,
  `name` varchar(100) DEFAULT NULL,
  `phone1` varchar(11) DEFAULT NULL,
  `phone2` varchar(11) DEFAULT NULL,
  `parmanent_address` varchar(250) DEFAULT NULL,
  `present_address` varchar(250) DEFAULT NULL,
  `reference_phone` varchar(11) DEFAULT NULL,
  `reference_name` varchar(25) DEFAULT NULL,
  `nid_number` varchar(50) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=latin1;

-- Structure for Table `billing_migrate_transactions` 

DROP TABLE IF EXISTS `billing_migrate_transactions`; 

CREATE TABLE `billing_migrate_transactions` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `pairing_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `lco_id` int(11) DEFAULT NULL,
  `package_id` varchar(200) DEFAULT NULL COMMENT 'should be comma seperated value',
  `payment_method_id` int(11) DEFAULT NULL,
  `transaction_types` varchar(1) DEFAULT NULL COMMENT 'D or C',
  `credit` decimal(10,0) DEFAULT '0' COMMENT 'Amount',
  `debit` decimal(10,0) DEFAULT '0' COMMENT 'Amount',
  `discount` decimal(10,0) DEFAULT NULL COMMENT 'if any or Zero',
  `vat_amount` decimal(10,0) DEFAULT NULL COMMENT 'Not in %, Should be calculated figure, if any',
  `balance` decimal(10,0) DEFAULT NULL COMMENT 'Total Amount/Final',
  `payment_type` enum('OTC','MRC') DEFAULT NULL,
  `vod` tinyint(1) DEFAULT '0',
  `user_package_assign_type_id` int(11) DEFAULT NULL,
  `demo` tinyint(1) DEFAULT '0',
  `collection_date` datetime DEFAULT NULL COMMENT 'Collection date from market',
  `transaction_date` datetime DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=40058 DEFAULT CHARSET=latin1;

-- Structure for Table `billing_money_receipt_books` 

DROP TABLE IF EXISTS `billing_money_receipt_books`; 

CREATE TABLE `billing_money_receipt_books` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) DEFAULT NULL,
  `collector_id` int(11) DEFAULT NULL,
  `money_receipt_book_number` varchar(100) DEFAULT NULL,
  `from` int(10) DEFAULT NULL,
  `to` int(10) DEFAULT NULL,
  `number_of_page` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=latin1;

-- Structure for Table `billing_money_receipts` 

DROP TABLE IF EXISTS `billing_money_receipts`; 

CREATE TABLE `billing_money_receipts` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) DEFAULT NULL,
  `collector_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `money_receipt_number` varchar(100) DEFAULT NULL,
  `money_receipt_book_number` varchar(100) DEFAULT NULL,
  `is_used` tinyint(1) DEFAULT '0',
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `NewIndex1` (`lco_id`,`collector_id`,`subscriber_id`,`money_receipt_number`,`money_receipt_book_number`)
) ENGINE=InnoDB AUTO_INCREMENT=32 DEFAULT CHARSET=latin1;

-- Structure for Table `billing_payment_methods` 

DROP TABLE IF EXISTS `billing_payment_methods`; 

CREATE TABLE `billing_payment_methods` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `method` varchar(100) DEFAULT NULL COMMENT '''CreditCard'',''Cash'',''BKash''',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=8 DEFAULT CHARSET=latin1;

-- Structure for Table `billing_pos_transactions` 

DROP TABLE IF EXISTS `billing_pos_transactions`; 

CREATE TABLE `billing_pos_transactions` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `pos_id` int(11) DEFAULT NULL,
  `date` date DEFAULT NULL,
  `time` varchar(10) DEFAULT NULL,
  `pairing_id` varchar(100) DEFAULT NULL,
  `mid` varchar(20) DEFAULT NULL,
  `tid` varchar(20) DEFAULT NULL,
  `subscriber_transaction_id` int(11) DEFAULT NULL,
  `batch_no` varchar(10) DEFAULT NULL,
  `invoice_no` varchar(10) DEFAULT NULL,
  `last_four` varchar(4) DEFAULT NULL,
  `payment_type_id` int(11) DEFAULT NULL,
  `approval_code` varchar(10) DEFAULT NULL,
  `rpn` varchar(20) DEFAULT NULL,
  `amount` decimal(10,0) DEFAULT NULL,
  `lco_id` int(11) DEFAULT NULL,
  `collector_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `billing_scratch_transactions` 

DROP TABLE IF EXISTS `billing_scratch_transactions`; 

CREATE TABLE `billing_scratch_transactions` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `pairing_id` int(11) DEFAULT NULL,
  `subscriber_transaction_id` int(11) DEFAULT NULL,
  `serial_no` varchar(100) DEFAULT NULL,
  `card_no` varchar(100) DEFAULT NULL,
  `amount` decimal(10,0) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=10055 DEFAULT CHARSET=latin1;

-- Structure for Table `billing_subscriber_transactions` 

DROP TABLE IF EXISTS `billing_subscriber_transactions`; 

CREATE TABLE `billing_subscriber_transactions` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `pairing_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `lco_id` int(11) DEFAULT NULL,
  `package_id` varchar(200) DEFAULT NULL COMMENT 'should be comma seperated value',
  `payment_method_id` int(11) DEFAULT NULL,
  `transaction_types` varchar(1) DEFAULT NULL COMMENT 'D or C',
  `credit` decimal(10,0) DEFAULT '0' COMMENT 'Amount',
  `debit` decimal(10,0) DEFAULT '0' COMMENT 'Amount',
  `discount` decimal(10,0) DEFAULT NULL COMMENT 'if any or Zero',
  `vat_amount` decimal(10,0) DEFAULT NULL COMMENT 'Not in %, Should be calculated figure, if any',
  `balance` decimal(10,0) DEFAULT NULL COMMENT 'Total Amount/Final',
  `payment_type` enum('OTC','MRC') DEFAULT NULL,
  `vod` tinyint(1) DEFAULT '0',
  `user_package_assign_type_id` int(11) DEFAULT NULL,
  `demo` tinyint(1) DEFAULT '0',
  `collection_date` datetime DEFAULT NULL COMMENT 'Collection date from market',
  `transaction_date` datetime DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=40162 DEFAULT CHARSET=latin1;

-- Structure for Table `card_distribution_lists` 

DROP TABLE IF EXISTS `card_distribution_lists`; 

CREATE TABLE `card_distribution_lists` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `card_info_id` int(11) DEFAULT NULL,
  `parent_id` int(5) DEFAULT NULL,
  `group_id` int(10) DEFAULT '0',
  `lco_id` int(5) DEFAULT '0',
  `from` varchar(1000) DEFAULT NULL,
  `to` varchar(1000) DEFAULT NULL,
  `total` varchar(1000) DEFAULT NULL,
  `updated_by` int(5) DEFAULT NULL,
  `created_by` int(5) DEFAULT NULL,
  `updated_at` varchar(20) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=281 DEFAULT CHARSET=latin1;

-- Structure for Table `cas_sms_response_codes` 

DROP TABLE IF EXISTS `cas_sms_response_codes`; 

CREATE TABLE `cas_sms_response_codes` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `hex_error_code` varchar(20) DEFAULT NULL,
  `decimal_error_code` varchar(20) DEFAULT NULL,
  `details` varchar(200) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=111 DEFAULT CHARSET=latin1;

-- Structure for Table `color_types` 

DROP TABLE IF EXISTS `color_types`; 

CREATE TABLE `color_types` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) DEFAULT NULL,
  `value` varchar(100) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=latin1;

-- Structure for Table `condition_mail_log` 

DROP TABLE IF EXISTS `condition_mail_log`; 

CREATE TABLE `condition_mail_log` (
  `id` bigint(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) NOT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `region_code` varchar(50) DEFAULT NULL,
  `stb_id` varchar(500) DEFAULT NULL,
  `smart_card_ext_id` varchar(100) DEFAULT NULL,
  `smart_card_id` varchar(100) DEFAULT NULL,
  `group_id` int(11) DEFAULT NULL,
  `start_time` datetime DEFAULT NULL,
  `end_time` datetime DEFAULT NULL,
  `mail_title` varchar(50) DEFAULT NULL,
  `mail_content` varchar(500) DEFAULT NULL,
  `mail_sign` varchar(100) DEFAULT NULL,
  `mail_priority` varchar(10) DEFAULT NULL,
  `condition_return_code` varchar(200) DEFAULT NULL,
  `is_stoped` tinyint(1) DEFAULT NULL,
  `type` enum('USER','SYSTEM') DEFAULT NULL,
  `creator` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `stopped_editor` int(11) DEFAULT NULL,
  `stopped_edit_time` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=36758 DEFAULT CHARSET=latin1;

-- Structure for Table `condition_search_log` 

DROP TABLE IF EXISTS `condition_search_log`; 

CREATE TABLE `condition_search_log` (
  `id` bigint(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) NOT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `region_code` varchar(50) DEFAULT NULL,
  `stb_id` varchar(500) DEFAULT NULL,
  `smart_card_id` varchar(100) DEFAULT NULL,
  `group_id` int(11) DEFAULT NULL,
  `condition_return_code` varchar(200) DEFAULT NULL,
  `start_time` datetime DEFAULT NULL,
  `end_time` datetime DEFAULT NULL,
  `is_stoped` tinyint(1) DEFAULT NULL,
  `creator` int(11) NOT NULL,
  `create_time` datetime DEFAULT NULL,
  `stopped_editor` int(11) DEFAULT NULL,
  `stopped_edit_time` datetime DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=latin1;

-- Structure for Table `conditional_limited_logs` 

DROP TABLE IF EXISTS `conditional_limited_logs`; 

CREATE TABLE `conditional_limited_logs` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `stb_id` int(11) DEFAULT NULL,
  `smart_card_id` int(11) DEFAULT NULL,
  `region_code` varchar(100) DEFAULT NULL,
  `group_id` int(11) DEFAULT NULL,
  `product_count` varchar(50) DEFAULT NULL,
  `product_id` varchar(50) DEFAULT NULL,
  `start_time` datetime DEFAULT NULL,
  `end_time` datetime DEFAULT NULL,
  `condition_return_code` varchar(100) DEFAULT NULL,
  `is_stoped` tinyint(1) DEFAULT '0',
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `stopped_editor` int(11) DEFAULT NULL,
  `stopped_edit_time` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `countries` 

DROP TABLE IF EXISTS `countries`; 

CREATE TABLE `countries` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `country_name` varchar(40) NOT NULL,
  `country_code` varchar(10) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;

-- Structure for Table `currencies` 

DROP TABLE IF EXISTS `currencies`; 

CREATE TABLE `currencies` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `currency_name` varchar(20) DEFAULT NULL,
  `currency_code` varchar(5) DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=latin1;

-- Structure for Table `delete_pairing_logs` 

DROP TABLE IF EXISTS `delete_pairing_logs`; 

CREATE TABLE `delete_pairing_logs` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `pairing_id` varchar(255) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `lco_id` int(11) DEFAULT NULL,
  `execution_date` date DEFAULT NULL,
  `stb_external_number` varchar(16) DEFAULT NULL,
  `ic_external_number` varchar(16) DEFAULT NULL,
  `package_id` varchar(255) DEFAULT NULL,
  `refund_amount` varchar(255) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=59 DEFAULT CHARSET=latin1;

-- Structure for Table `display_positions` 

DROP TABLE IF EXISTS `display_positions`; 

CREATE TABLE `display_positions` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) DEFAULT NULL,
  `value` varchar(100) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=latin1;

-- Structure for Table `distributors` 

DROP TABLE IF EXISTS `distributors`; 

CREATE TABLE `distributors` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) DEFAULT NULL,
  `distributor_name` varchar(100) DEFAULT NULL,
  `phone1` varchar(11) DEFAULT NULL,
  `phone2` varchar(11) DEFAULT NULL,
  `parmanent_address` varchar(250) DEFAULT NULL,
  `present_address` varchar(250) DEFAULT NULL,
  `reference_phone` varchar(11) DEFAULT NULL,
  `reference_name` varchar(25) DEFAULT NULL,
  `nid_number` varchar(50) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=latin1;

-- Structure for Table `districts` 

DROP TABLE IF EXISTS `districts`; 

CREATE TABLE `districts` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `district_name` varchar(40) NOT NULL,
  `district_code` varchar(10) DEFAULT NULL,
  `country_id` int(11) DEFAULT NULL,
  `division_id` int(11) NOT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fk_districts_divisions1_idx` (`division_id`),
  KEY `FK_districts_countries` (`country_id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;

-- Structure for Table `divisions` 

DROP TABLE IF EXISTS `divisions`; 

CREATE TABLE `divisions` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `division_name` varchar(100) NOT NULL,
  `division_code` varchar(10) DEFAULT NULL,
  `country_id` int(11) NOT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`,`division_name`),
  KEY `fk_divisions_countries1_idx` (`country_id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;

-- Structure for Table `ecm_fingerprint_logs` 

DROP TABLE IF EXISTS `ecm_fingerprint_logs`; 

CREATE TABLE `ecm_fingerprint_logs` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `stb_id` int(11) DEFAULT NULL,
  `smart_card_id` int(11) DEFAULT NULL,
  `region_code` varchar(100) DEFAULT NULL,
  `group_id` int(11) DEFAULT NULL,
  `program_count` varchar(50) DEFAULT NULL,
  `program_id` varchar(50) DEFAULT NULL,
  `start_time` datetime DEFAULT NULL,
  `end_time` datetime DEFAULT NULL,
  `condition_return_code` varchar(100) DEFAULT NULL,
  `is_stoped` tinyint(1) DEFAULT '0',
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `stopped_editor` int(11) DEFAULT NULL,
  `stopped_edit_time` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `emm_fingerprint_logs` 

DROP TABLE IF EXISTS `emm_fingerprint_logs`; 

CREATE TABLE `emm_fingerprint_logs` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `stb_id` int(11) DEFAULT NULL,
  `smart_card_id` int(11) DEFAULT NULL,
  `region_code` varchar(100) DEFAULT NULL,
  `group_id` int(11) DEFAULT NULL,
  `position_flag` varchar(50) DEFAULT NULL,
  `show_time` varchar(50) DEFAULT NULL,
  `stop_time` varchar(50) DEFAULT NULL,
  `font_size` varchar(50) DEFAULT NULL,
  `font_type` varchar(50) DEFAULT NULL,
  `color_type` varchar(50) DEFAULT NULL,
  `font_color` varchar(50) DEFAULT NULL,
  `back_color` varchar(50) DEFAULT NULL,
  `overt_flag` varchar(50) DEFAULT NULL,
  `show_bk_flag` varchar(50) DEFAULT NULL,
  `show_stb_number_flag` varchar(50) DEFAULT NULL,
  `x_pos` varchar(50) DEFAULT NULL,
  `y_pos` varchar(50) DEFAULT NULL,
  `start_time` datetime DEFAULT NULL,
  `end_time` datetime DEFAULT NULL,
  `condition_return_code` varchar(100) DEFAULT NULL,
  `is_stoped` tinyint(1) DEFAULT '0',
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `stopped_editor` int(11) DEFAULT NULL,
  `stopped_edit_time` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `fonts` 

DROP TABLE IF EXISTS `fonts`; 

CREATE TABLE `fonts` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) DEFAULT NULL,
  `value` varchar(100) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=12 DEFAULT CHARSET=latin1;

-- Structure for Table `force_osd_logs` 

DROP TABLE IF EXISTS `force_osd_logs`; 

CREATE TABLE `force_osd_logs` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `stb_id` int(11) DEFAULT NULL,
  `smart_card_id` int(11) DEFAULT NULL,
  `region_code` varchar(100) DEFAULT NULL,
  `group_id` int(11) DEFAULT NULL,
  `content` text,
  `ratio` varchar(50) DEFAULT NULL,
  `show_time` varchar(50) DEFAULT NULL,
  `stop_time` varchar(50) DEFAULT NULL,
  `font_size` varchar(50) DEFAULT NULL,
  `font_type` varchar(50) DEFAULT NULL,
  `color_type` varchar(50) DEFAULT NULL,
  `font_color` varchar(50) DEFAULT NULL,
  `background_color` varchar(50) DEFAULT NULL,
  `clarity` varchar(50) DEFAULT NULL,
  `program_count` varchar(50) DEFAULT NULL,
  `program_id` varchar(50) DEFAULT NULL,
  `start_time` datetime DEFAULT NULL,
  `end_time` datetime DEFAULT NULL,
  `condition_return_code` varchar(100) DEFAULT NULL,
  `is_stoped` tinyint(1) DEFAULT '0',
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `stopped_editor` int(11) DEFAULT NULL,
  `stopped_edit_time` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `ftp_accounts` 

DROP TABLE IF EXISTS `ftp_accounts`; 

CREATE TABLE `ftp_accounts` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `server_ip` varchar(16) DEFAULT NULL,
  `server_port` varchar(4) DEFAULT NULL,
  `user_id` varchar(255) DEFAULT NULL,
  `password` varchar(255) DEFAULT NULL,
  `dir_location` text,
  `default` tinyint(1) DEFAULT '1',
  `created_by` int(11) DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=latin1;

-- Structure for Table `ftp_transfer_logs` 

DROP TABLE IF EXISTS `ftp_transfer_logs`; 

CREATE TABLE `ftp_transfer_logs` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `ftp_account_id` int(11) DEFAULT NULL,
  `file_name` varchar(255) DEFAULT NULL,
  `status` tinyint(1) DEFAULT '0',
  `done_time` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=latin1;

-- Structure for Table `group_profiles` 

DROP TABLE IF EXISTS `group_profiles`; 

CREATE TABLE `group_profiles` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `group_name` varchar(255) DEFAULT NULL,
  `address1` text,
  `address2` text,
  `country_id` int(11) DEFAULT NULL,
  `division_id` int(11) DEFAULT NULL,
  `district_id` int(11) DEFAULT NULL,
  `area_id` int(11) DEFAULT NULL,
  `sub_area_id` int(11) DEFAULT NULL,
  `road_id` int(11) DEFAULT NULL,
  `photo` text,
  `identity_type` varchar(10) DEFAULT NULL,
  `identity_number` varchar(20) DEFAULT NULL,
  `identity_attachment` text,
  `contact` varchar(11) DEFAULT NULL,
  `is_same_as_contact` tinyint(1) DEFAULT '0',
  `billing_contact` varchar(11) DEFAULT NULL,
  `business_modality` text,
  `region_l1_code` varchar(20) DEFAULT NULL,
  `region_l2_code` varchar(20) DEFAULT NULL,
  `region_l3_code` varchar(20) DEFAULT NULL,
  `region_l4_code` varchar(20) DEFAULT NULL,
  `message_sign` varchar(10) DEFAULT NULL,
  `token` varchar(40) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  `post_code` varchar(10) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fk_profiles_areas1_idx` (`area_id`),
  KEY `fk_profiles_districts1_idx` (`district_id`),
  KEY `fk_profiles_divisions1_idx` (`division_id`),
  KEY `fk_profiles_countries1_idx` (`country_id`)
) ENGINE=InnoDB AUTO_INCREMENT=17 DEFAULT CHARSET=utf8;

-- Structure for Table `last_scratch_card_info` 

DROP TABLE IF EXISTS `last_scratch_card_info`; 

CREATE TABLE `last_scratch_card_info` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `card_no` varchar(16) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=latin1;

-- Structure for Table `lco_groups` 

DROP TABLE IF EXISTS `lco_groups`; 

CREATE TABLE `lco_groups` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) DEFAULT NULL,
  `group_id` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=152 DEFAULT CHARSET=latin1;

-- Structure for Table `lco_profiles` 

DROP TABLE IF EXISTS `lco_profiles`; 

CREATE TABLE `lco_profiles` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_name` varchar(255) DEFAULT NULL,
  `address1` text,
  `address2` text,
  `country_id` int(11) DEFAULT NULL,
  `division_id` int(11) DEFAULT NULL,
  `district_id` int(11) DEFAULT NULL,
  `area_id` int(11) DEFAULT NULL,
  `sub_area_id` int(11) DEFAULT NULL,
  `road_id` int(11) DEFAULT NULL,
  `photo` text,
  `identity_type` varchar(10) DEFAULT NULL,
  `identity_number` varchar(20) DEFAULT NULL,
  `identity_attachment` text,
  `contact` varchar(11) DEFAULT NULL,
  `is_same_as_contact` tinyint(1) DEFAULT '0',
  `billing_contact` varchar(11) DEFAULT NULL,
  `business_modality` text,
  `region_l1_code` varchar(20) DEFAULT NULL,
  `region_l2_code` varchar(20) DEFAULT NULL,
  `region_l3_code` varchar(20) DEFAULT NULL,
  `region_l4_code` varchar(20) DEFAULT NULL,
  `message_sign` varchar(10) DEFAULT NULL,
  `token` varchar(40) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  `post_code` varchar(10) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fk_profiles_areas1_idx` (`area_id`),
  KEY `fk_profiles_districts1_idx` (`district_id`),
  KEY `fk_profiles_divisions1_idx` (`division_id`),
  KEY `fk_profiles_countries1_idx` (`country_id`)
) ENGINE=InnoDB AUTO_INCREMENT=110 DEFAULT CHARSET=utf8;

-- Structure for Table `mso_profiles` 

DROP TABLE IF EXISTS `mso_profiles`; 

CREATE TABLE `mso_profiles` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `mso_name` varchar(255) DEFAULT NULL,
  `address1` text,
  `address2` text,
  `country_id` int(11) DEFAULT NULL,
  `division_id` int(11) DEFAULT NULL,
  `district_id` int(11) DEFAULT NULL,
  `area_id` int(11) DEFAULT NULL,
  `sub_area_id` int(11) DEFAULT NULL,
  `road_id` int(11) DEFAULT NULL,
  `identity_type` varchar(10) DEFAULT NULL,
  `identity_number` varchar(20) DEFAULT NULL,
  `photo` text,
  `identity_attachment` text,
  `contact` varchar(11) DEFAULT NULL,
  `billing_contact` varchar(11) DEFAULT NULL,
  `token` varchar(40) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  `post_code` varchar(10) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fk_profiles_areas1_idx` (`area_id`),
  KEY `fk_profiles_districts1_idx` (`district_id`),
  KEY `fk_profiles_divisions1_idx` (`division_id`),
  KEY `fk_profiles_countries1_idx` (`country_id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;

-- Structure for Table `notifications` 

DROP TABLE IF EXISTS `notifications`; 

CREATE TABLE `notifications` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `title` varchar(100) DEFAULT NULL,
  `description` text,
  `mso_id` int(11) DEFAULT NULL,
  `lco_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT '0',
  `group_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `is_read_mso` tinyint(4) DEFAULT NULL,
  `is_read_lco` tinyint(4) DEFAULT NULL,
  `is_read_subscriber` tinyint(1) DEFAULT '0',
  `is_read_group` tinyint(1) DEFAULT '0',
  `lco_updated_at` datetime DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=55262 DEFAULT CHARSET=latin1;

-- Structure for Table `organization_info` 

DROP TABLE IF EXISTS `organization_info`; 

CREATE TABLE `organization_info` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `organization_name` varchar(100) DEFAULT NULL,
  `organization_phone` varchar(20) DEFAULT NULL,
  `organization_email` varchar(100) DEFAULT NULL,
  `copyright_year` varchar(4) DEFAULT NULL,
  `operator_id` varchar(4) DEFAULT NULL,
  `gift_amount` int(4) DEFAULT NULL,
  `administrator1` varchar(100) DEFAULT NULL,
  `is_show` int(1) DEFAULT '0',
  `phone1` varchar(15) DEFAULT NULL,
  `administrator2` varchar(100) DEFAULT NULL,
  `phone2` varchar(15) DEFAULT NULL,
  `logo` text,
  `icon` text,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=24 DEFAULT CHARSET=latin1 CHECKSUM=1 DELAY_KEY_WRITE=1 ROW_FORMAT=DYNAMIC;

-- Structure for Table `ownership_transfers` 

DROP TABLE IF EXISTS `ownership_transfers`; 

CREATE TABLE `ownership_transfers` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `old_id` int(11) DEFAULT NULL,
  `pairing_id` int(8) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `lco_id` int(11) DEFAULT NULL,
  `stb_id` int(11) DEFAULT NULL,
  `card_id` int(11) DEFAULT NULL,
  `is_cas_pairing` tinyint(1) DEFAULT '0',
  `free_stb` tinyint(1) DEFAULT '0',
  `free_card` tinyint(1) DEFAULT '0',
  `free_subscription_fee` tinyint(1) DEFAULT '0',
  `remarks` text,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `NewIndex1` (`subscriber_id`,`lco_id`,`stb_id`,`card_id`,`created_by`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `package_programs` 

DROP TABLE IF EXISTS `package_programs`; 

CREATE TABLE `package_programs` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `package_id` int(11) NOT NULL,
  `program_id` int(11) NOT NULL,
  `is_active` tinyint(1) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fk_package_program_programs1_idx` (`package_id`),
  KEY `fk_package_program_packages1_idx` (`program_id`)
) ENGINE=InnoDB AUTO_INCREMENT=3114 DEFAULT CHARSET=utf8;

-- Structure for Table `packages` 

DROP TABLE IF EXISTS `packages`; 

CREATE TABLE `packages` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `package_name` varchar(40) DEFAULT NULL,
  `limit_flag` tinyint(1) DEFAULT NULL,
  `duration` int(10) DEFAULT NULL,
  `price` decimal(20,0) DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT '1' COMMENT 'is_active',
  `last_editor` varchar(50) DEFAULT NULL,
  `last_edit_time` datetime DEFAULT NULL,
  `match_flag` tinyint(1) DEFAULT NULL,
  `is_add_on` tinyint(1) DEFAULT '0',
  `token` varchar(40) NOT NULL,
  `is_deleted` tinyint(1) DEFAULT '0',
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) NOT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;

-- Structure for Table `pair_stb_ic_logs` 

DROP TABLE IF EXISTS `pair_stb_ic_logs`; 

CREATE TABLE `pair_stb_ic_logs` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `pairing_id` varchar(20) DEFAULT NULL,
  `condition` tinyint(4) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `type` enum('USER','SYSTEM') DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `payment_types` 

DROP TABLE IF EXISTS `payment_types`; 

CREATE TABLE `payment_types` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `payment_type` varchar(20) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=latin1;

-- Structure for Table `plaas_menus` 

DROP TABLE IF EXISTS `plaas_menus`; 

CREATE TABLE `plaas_menus` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `module_id` int(11) DEFAULT '1',
  `menu_name` varchar(100) DEFAULT NULL,
  `route` varchar(100) DEFAULT NULL,
  `display_order` int(11) DEFAULT NULL,
  `parent` int(11) DEFAULT NULL,
  `menu_type` enum('MSO','LCO','Subscriber','Group') DEFAULT NULL,
  `visible` tinyint(1) DEFAULT '1',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=185 DEFAULT CHARSET=latin1;

-- Structure for Table `plaas_modules` 

DROP TABLE IF EXISTS `plaas_modules`; 

CREATE TABLE `plaas_modules` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `module_code` varchar(5) NOT NULL,
  `module_name` varchar(100) NOT NULL,
  `module_description` varchar(300) DEFAULT NULL,
  `created_by` int(4) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_by` int(4) DEFAULT NULL,
  `updated_at` date DEFAULT NULL,
  `is_active` int(1) NOT NULL DEFAULT '1',
  `route` varchar(200) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=latin1;

-- Structure for Table `plaas_role_menu_privileges` 

DROP TABLE IF EXISTS `plaas_role_menu_privileges`; 

CREATE TABLE `plaas_role_menu_privileges` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `role_id` int(11) DEFAULT NULL,
  `module_id` int(11) DEFAULT NULL,
  `menu_id` int(11) DEFAULT NULL,
  `view` tinyint(1) DEFAULT '0',
  `create` tinyint(1) DEFAULT '0',
  `edit` tinyint(1) DEFAULT '0',
  `delete` tinyint(1) DEFAULT '0',
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=123 DEFAULT CHARSET=latin1;

-- Structure for Table `plaas_role_module_privileges` 

DROP TABLE IF EXISTS `plaas_role_module_privileges`; 

CREATE TABLE `plaas_role_module_privileges` (
  `id` int(11) DEFAULT NULL,
  `role_id` int(11) DEFAULT NULL,
  `module_id` int(11) DEFAULT NULL,
  `view` tinyint(1) DEFAULT NULL,
  `insert` tinyint(1) DEFAULT NULL,
  `update` tinyint(1) DEFAULT NULL,
  `delete` tinyint(1) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `pos_machines` 

DROP TABLE IF EXISTS `pos_machines`; 

CREATE TABLE `pos_machines` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `bank_account_id` int(11) DEFAULT NULL,
  `pos_machine_id` varchar(100) DEFAULT NULL,
  `collector_id` int(11) DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT '0',
  `charge_interest` varchar(100) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `token` varchar(50) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `post_codes` 

DROP TABLE IF EXISTS `post_codes`; 

CREATE TABLE `post_codes` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `country_id` int(11) DEFAULT NULL,
  `division_id` int(11) DEFAULT NULL,
  `district_id` int(11) DEFAULT NULL,
  `post_code` varchar(10) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `priorities` 

DROP TABLE IF EXISTS `priorities`; 

CREATE TABLE `priorities` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) DEFAULT NULL,
  `value` varchar(100) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=latin1;

-- Structure for Table `programs` 

DROP TABLE IF EXISTS `programs`; 

CREATE TABLE `programs` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lcn` int(10) DEFAULT NULL,
  `program_service_id` varchar(20) DEFAULT '0',
  `program_name` varchar(100) DEFAULT NULL,
  `fingerprint` tinyint(1) DEFAULT '0',
  `display_position` varchar(64) DEFAULT NULL,
  `font_type` int(11) DEFAULT NULL,
  `font_color` int(11) unsigned DEFAULT NULL,
  `font_size` int(11) unsigned DEFAULT NULL,
  `background_color` int(11) DEFAULT NULL,
  `visible_level` char(1) DEFAULT NULL,
  `program_type` varchar(64) DEFAULT NULL,
  `status` tinyint(1) DEFAULT '1',
  `last_editor` varchar(50) DEFAULT NULL,
  `last_edit_time` datetime DEFAULT NULL,
  `network_id` varchar(64) DEFAULT NULL,
  `transport_stream_id` varchar(64) DEFAULT NULL,
  `service_id` varchar(64) DEFAULT NULL,
  `position_x` smallint(6) DEFAULT NULL,
  `position_y` smallint(6) DEFAULT NULL,
  `color_type` int(11) DEFAULT '3',
  `show_time` int(11) DEFAULT NULL,
  `stop_time` int(11) DEFAULT NULL,
  `over_flag` tinyint(4) DEFAULT NULL,
  `show_background_flag` tinyint(4) DEFAULT NULL,
  `show_stb_number_flag` tinyint(4) DEFAULT NULL,
  `program_status` tinyint(1) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=191 DEFAULT CHARSET=utf8;

-- Structure for Table `references` 

DROP TABLE IF EXISTS `references`; 

CREATE TABLE `references` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `region_level_1` 

DROP TABLE IF EXISTS `region_level_1`; 

CREATE TABLE `region_level_1` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `region_l1_name` varchar(50) DEFAULT NULL,
  `region_l1_code` int(11) DEFAULT '0',
  `region_l2_code` int(11) DEFAULT '0',
  `region_l3_code` int(11) DEFAULT '0',
  `region_l4_code` int(11) DEFAULT '0',
  `hex_code` varchar(200) DEFAULT '0',
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT '1',
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=latin1 CHECKSUM=1 DELAY_KEY_WRITE=1 ROW_FORMAT=DYNAMIC;

-- Structure for Table `region_level_2` 

DROP TABLE IF EXISTS `region_level_2`; 

CREATE TABLE `region_level_2` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `region_l2_name` varchar(50) DEFAULT NULL,
  `region_l1_code` int(11) DEFAULT '0',
  `region_l2_code` int(11) DEFAULT '0',
  `region_l3_code` int(11) DEFAULT '0',
  `region_l4_code` int(11) DEFAULT '0',
  `hex_code` varchar(200) DEFAULT '0',
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT '1',
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=latin1 CHECKSUM=1 DELAY_KEY_WRITE=1 ROW_FORMAT=DYNAMIC;

-- Structure for Table `region_level_3` 

DROP TABLE IF EXISTS `region_level_3`; 

CREATE TABLE `region_level_3` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `region_l3_name` varchar(50) DEFAULT NULL,
  `region_l1_code` int(11) DEFAULT '0',
  `region_l2_code` int(11) DEFAULT '0',
  `region_l3_code` int(11) DEFAULT '0',
  `region_l4_code` int(11) DEFAULT '0',
  `hex_code` varchar(200) DEFAULT '0',
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT '1',
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=86 DEFAULT CHARSET=latin1 CHECKSUM=1 DELAY_KEY_WRITE=1 ROW_FORMAT=DYNAMIC;

-- Structure for Table `region_level_4` 

DROP TABLE IF EXISTS `region_level_4`; 

CREATE TABLE `region_level_4` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `region_l4_name` varchar(50) DEFAULT NULL,
  `region_l1_code` int(11) DEFAULT '0',
  `region_l2_code` int(11) DEFAULT '0',
  `region_l3_code` int(11) DEFAULT '0',
  `region_l4_code` int(11) DEFAULT '0',
  `hex_code` varchar(200) DEFAULT '0',
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT '1',
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=27 DEFAULT CHARSET=latin1 CHECKSUM=1 DELAY_KEY_WRITE=1 ROW_FORMAT=DYNAMIC;

-- Structure for Table `roads` 

DROP TABLE IF EXISTS `roads`; 

CREATE TABLE `roads` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `road_name` varchar(100) NOT NULL,
  `road_code` varchar(10) DEFAULT NULL,
  `country_id` int(11) DEFAULT NULL,
  `division_id` int(11) DEFAULT NULL,
  `district_id` int(11) NOT NULL,
  `area_id` int(11) DEFAULT NULL,
  `sub_area_id` int(11) DEFAULT NULL,
  `lat` varchar(255) DEFAULT NULL,
  `lon` varchar(255) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `FK_areas` (`country_id`),
  KEY `FK_area_division1` (`division_id`),
  KEY `FK_areas_district` (`district_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Structure for Table `roles` 

DROP TABLE IF EXISTS `roles`; 

CREATE TABLE `roles` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `user_type` enum('MSO','LCO','Staff','Subscriber','Group') DEFAULT NULL,
  `role_type` enum('admin','staff','subscriber') DEFAULT NULL,
  `role_name` varchar(45) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `default_role` tinyint(1) DEFAULT '0',
  `status` tinyint(1) DEFAULT '1',
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=12 DEFAULT CHARSET=utf8;

-- Structure for Table `scratch_card_detail` 

DROP TABLE IF EXISTS `scratch_card_detail`; 

CREATE TABLE `scratch_card_detail` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `card_info_id` int(11) DEFAULT NULL,
  `card_no` varchar(100) DEFAULT NULL,
  `serial_no` varchar(8) DEFAULT NULL,
  `parent_id` int(5) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT '0',
  `user_type` enum('MSO','LCO','Group') DEFAULT NULL,
  `group_id` int(10) DEFAULT '0',
  `lco_id` int(5) DEFAULT '0',
  `distributor_id` int(5) DEFAULT '0',
  `used_date` varchar(20) DEFAULT NULL,
  `ip_location` varchar(250) DEFAULT NULL,
  `is_used` int(1) DEFAULT '0',
  `is_active` int(1) DEFAULT '1',
  `is_suspended` int(1) DEFAULT '0',
  `updated_by` int(5) DEFAULT NULL,
  `created_by` int(5) DEFAULT NULL,
  `updated_at` varchar(20) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=24712 DEFAULT CHARSET=latin1;

-- Structure for Table `scratch_card_info` 

DROP TABLE IF EXISTS `scratch_card_info`; 

CREATE TABLE `scratch_card_info` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `prefix` int(2) DEFAULT NULL,
  `length` int(11) DEFAULT NULL,
  `batch_no` bigint(12) DEFAULT NULL,
  `value` float DEFAULT NULL,
  `number_of_cards` int(11) DEFAULT NULL,
  `active_from_date` varchar(20) DEFAULT NULL,
  `is_active` int(1) DEFAULT '1',
  `is_suspended` int(1) DEFAULT '0',
  `created_by` int(5) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `parent_id` int(5) DEFAULT NULL,
  `updated_by` int(5) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=20 DEFAULT CHARSET=latin1;

-- Structure for Table `scrolling_osd_logs` 

DROP TABLE IF EXISTS `scrolling_osd_logs`; 

CREATE TABLE `scrolling_osd_logs` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lco_id` int(11) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `stb_id` int(11) DEFAULT NULL,
  `smart_card_id` int(11) DEFAULT NULL,
  `region_code` varchar(100) DEFAULT NULL,
  `group_id` int(11) DEFAULT NULL,
  `settings_id` int(11) DEFAULT NULL,
  `display_times` varchar(10) DEFAULT NULL,
  `content` text,
  `start_time` datetime DEFAULT NULL,
  `end_time` datetime DEFAULT NULL,
  `condition_return_code` varchar(100) DEFAULT NULL,
  `is_stoped` tinyint(1) DEFAULT '0',
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `stopped_editor` int(11) DEFAULT NULL,
  `stopped_edit_time` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=latin1;

-- Structure for Table `scrolling_osd_settings` 

DROP TABLE IF EXISTS `scrolling_osd_settings`; 

CREATE TABLE `scrolling_osd_settings` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) DEFAULT NULL,
  `priority` varchar(10) DEFAULT NULL,
  `position` varchar(10) DEFAULT NULL,
  `size` varchar(10) DEFAULT NULL,
  `type` varchar(20) DEFAULT NULL,
  `color_type` varchar(20) DEFAULT NULL,
  `font` varchar(20) DEFAULT NULL,
  `back_color` varchar(20) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `set_top_boxes` 

DROP TABLE IF EXISTS `set_top_boxes`; 

CREATE TABLE `set_top_boxes` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `internal_card_number` varchar(255) DEFAULT '0',
  `external_card_number` varchar(255) DEFAULT NULL,
  `stb_card_provider` int(11) DEFAULT NULL,
  `price` decimal(10,0) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `lco_id` int(11) DEFAULT NULL,
  `is_used` tinyint(1) DEFAULT '0',
  `used_date` datetime DEFAULT NULL COMMENT 'assigned to subscriber',
  `lco_assigned_date` datetime DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `NewIndex1` (`stb_card_provider`,`created_by`,`subscriber_id`,`lco_id`)
) ENGINE=InnoDB AUTO_INCREMENT=7403 DEFAULT CHARSET=latin1;

-- Structure for Table `sizes` 

DROP TABLE IF EXISTS `sizes`; 

CREATE TABLE `sizes` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) DEFAULT NULL,
  `value` varchar(100) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=13 DEFAULT CHARSET=latin1;

-- Structure for Table `smart_card_providers` 

DROP TABLE IF EXISTS `smart_card_providers`; 

CREATE TABLE `smart_card_providers` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `stb_type` varchar(100) DEFAULT NULL,
  `stb_provider` varchar(255) DEFAULT NULL,
  `description` varchar(500) DEFAULT NULL,
  `address1` varchar(250) DEFAULT NULL,
  `address2` varchar(250) DEFAULT NULL,
  `country` varchar(25) DEFAULT NULL,
  `state` varchar(25) DEFAULT NULL,
  `city` varchar(25) DEFAULT NULL,
  `zip` varchar(25) DEFAULT NULL,
  `email` varchar(100) DEFAULT NULL,
  `phone` varchar(20) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=latin1;

-- Structure for Table `smart_cards` 

DROP TABLE IF EXISTS `smart_cards`; 

CREATE TABLE `smart_cards` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `internal_card_number` varchar(255) DEFAULT NULL,
  `external_card_number` varchar(255) DEFAULT NULL,
  `smart_card_provider` int(11) DEFAULT NULL,
  `price` decimal(10,0) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `lco_id` int(11) DEFAULT NULL,
  `is_used` tinyint(1) NOT NULL DEFAULT '0',
  `used_date` datetime DEFAULT NULL,
  `lco_assigned_date` datetime DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `NewIndex1` (`smart_card_provider`,`subscriber_id`,`lco_id`,`created_by`)
) ENGINE=InnoDB AUTO_INCREMENT=7134 DEFAULT CHARSET=latin1;

-- Structure for Table `stb_providers` 

DROP TABLE IF EXISTS `stb_providers`; 

CREATE TABLE `stb_providers` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `stb_type` varchar(100) DEFAULT NULL,
  `stb_provider` varchar(255) DEFAULT NULL,
  `description` varchar(500) DEFAULT NULL,
  `address1` varchar(250) DEFAULT NULL,
  `address2` varchar(250) DEFAULT NULL,
  `country` varchar(25) DEFAULT NULL,
  `state` varchar(25) DEFAULT NULL,
  `city` varchar(25) DEFAULT NULL,
  `zip` varchar(25) DEFAULT NULL,
  `email` varchar(100) DEFAULT NULL,
  `phone` varchar(20) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=latin1;

-- Structure for Table `sub_areas` 

DROP TABLE IF EXISTS `sub_areas`; 

CREATE TABLE `sub_areas` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `sub_area_name` varchar(100) NOT NULL,
  `sub_area_code` varchar(10) DEFAULT NULL,
  `country_id` int(11) DEFAULT NULL,
  `division_id` int(11) DEFAULT NULL,
  `district_id` int(11) NOT NULL,
  `area_id` int(11) DEFAULT NULL,
  `lat` varchar(255) DEFAULT NULL,
  `lon` varchar(255) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `FK_areas` (`country_id`),
  KEY `FK_area_division1` (`division_id`),
  KEY `FK_areas_district` (`district_id`)
) ENGINE=InnoDB AUTO_INCREMENT=87 DEFAULT CHARSET=utf8;

-- Structure for Table `subscriber_parking_reassign_logs` 

DROP TABLE IF EXISTS `subscriber_parking_reassign_logs`; 

CREATE TABLE `subscriber_parking_reassign_logs` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `pairing_id` int(8) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `lco_id` int(11) DEFAULT NULL,
  `stb_id` int(11) DEFAULT NULL,
  `card_id` int(11) DEFAULT NULL,
  `stb_card_pairing_id` int(11) DEFAULT NULL,
  `parking_date` datetime DEFAULT NULL,
  `is_cas_pairing` tinyint(1) DEFAULT '0',
  `free_stb` tinyint(1) DEFAULT '0',
  `free_card` tinyint(1) DEFAULT '0',
  `free_subscription_fee` tinyint(1) DEFAULT '0',
  `status` tinyint(1) DEFAULT '0',
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=latin1;

-- Structure for Table `subscriber_parkings` 

DROP TABLE IF EXISTS `subscriber_parkings`; 

CREATE TABLE `subscriber_parkings` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `pairing_id` int(8) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `lco_id` int(11) DEFAULT NULL,
  `stb_id` int(11) DEFAULT NULL,
  `card_id` int(11) DEFAULT NULL,
  `stb_card_pairing_id` int(11) DEFAULT NULL,
  `parking_date` datetime DEFAULT NULL,
  `is_cas_pairing` tinyint(1) DEFAULT '0',
  `free_stb` tinyint(1) DEFAULT '0',
  `free_card` tinyint(1) DEFAULT '0',
  `free_subscription_fee` tinyint(1) DEFAULT '0',
  `status` tinyint(1) DEFAULT '0',
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=8 DEFAULT CHARSET=latin1;

-- Structure for Table `subscriber_profiles` 

DROP TABLE IF EXISTS `subscriber_profiles`; 

CREATE TABLE `subscriber_profiles` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `subscriber_name` varchar(64) DEFAULT NULL,
  `address1` text,
  `address2` text,
  `country_id` int(11) DEFAULT NULL,
  `division_id` int(11) DEFAULT NULL,
  `district_id` int(11) DEFAULT NULL,
  `area_id` int(11) DEFAULT NULL,
  `sub_area_id` int(11) DEFAULT NULL,
  `road_id` int(11) DEFAULT NULL,
  `contact` varchar(11) DEFAULT NULL,
  `is_same_as_contact` tinyint(1) DEFAULT '0',
  `billing_contact` varbinary(11) DEFAULT NULL,
  `photo` text,
  `identity_type` varchar(10) DEFAULT NULL,
  `identity_number` varchar(20) DEFAULT NULL,
  `identity_attachment` text,
  `subscription_copy` text,
  `region_l1_code` varchar(20) DEFAULT '0',
  `region_l2_code` varchar(20) DEFAULT '0',
  `region_l3_code` varchar(20) DEFAULT '0',
  `region_l4_code` varchar(20) DEFAULT '0',
  `lat` varchar(100) DEFAULT NULL,
  `long` varchar(100) DEFAULT NULL,
  `is_foc` tinyint(1) DEFAULT '0',
  `foc_control_room` tinyint(1) DEFAULT '0',
  `foc_others` tinyint(1) DEFAULT '0',
  `reference_type` varchar(10) DEFAULT NULL COMMENT 'LCO or Others',
  `reference_id` int(11) DEFAULT NULL,
  `remarks` text,
  `is_hide` tinyint(1) DEFAULT '0' COMMENT 'show_every_one',
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `token` varchar(60) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  `post_code` varchar(10) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=7317 DEFAULT CHARSET=latin1 CHECKSUM=1 DELAY_KEY_WRITE=1 ROW_FORMAT=DYNAMIC;

-- Structure for Table `subscriber_stb_smartcards` 

DROP TABLE IF EXISTS `subscriber_stb_smartcards`; 

CREATE TABLE `subscriber_stb_smartcards` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `pairing_id` int(8) DEFAULT NULL,
  `subscriber_id` int(11) DEFAULT NULL,
  `lco_id` int(11) DEFAULT NULL,
  `stb_id` int(11) DEFAULT NULL,
  `card_id` int(11) DEFAULT NULL,
  `is_cas_pairing` tinyint(1) DEFAULT '0',
  `free_stb` tinyint(1) DEFAULT '0',
  `free_card` tinyint(1) DEFAULT '0',
  `free_subscription_fee` tinyint(1) DEFAULT '0',
  `remarks` text,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `NewIndex1` (`subscriber_id`,`lco_id`,`stb_id`,`card_id`,`created_by`)
) ENGINE=InnoDB AUTO_INCREMENT=6616 DEFAULT CHARSET=latin1;

-- Structure for Table `types` 

DROP TABLE IF EXISTS `types`; 

CREATE TABLE `types` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) DEFAULT NULL,
  `value` varchar(100) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=latin1;

-- Structure for Table `user_addon_packages` 

DROP TABLE IF EXISTS `user_addon_packages`; 

CREATE TABLE `user_addon_packages` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `user_id` int(11) DEFAULT NULL,
  `package_id` int(11) DEFAULT NULL,
  `status` tinyint(1) DEFAULT NULL,
  `user_stb_smart_id` int(11) DEFAULT NULL,
  `package_start_date` datetime DEFAULT NULL,
  `package_expire_date` datetime DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `no_of_days` int(11) DEFAULT NULL,
  `user_package_type_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `update_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Structure for Table `user_package_assign_types` 

DROP TABLE IF EXISTS `user_package_assign_types`; 

CREATE TABLE `user_package_assign_types` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `type` varchar(200) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=latin1;

-- Structure for Table `user_packages` 

DROP TABLE IF EXISTS `user_packages`; 

CREATE TABLE `user_packages` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `user_id` int(11) NOT NULL,
  `package_id` int(11) NOT NULL,
  `user_stb_smart_id` int(11) DEFAULT NULL,
  `status` tinyint(1) DEFAULT NULL,
  `charge_type` tinyint(1) DEFAULT '0',
  `package_start_date` datetime DEFAULT NULL,
  `package_expire_date` datetime DEFAULT NULL,
  `no_of_days` int(11) DEFAULT NULL,
  `user_package_type_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fk_user_packages_users1_idx` (`user_id`),
  KEY `fk_user_packages_packages1_idx` (`package_id`)
) ENGINE=InnoDB AUTO_INCREMENT=8819 DEFAULT CHARSET=utf8;

-- Structure for Table `user_packages_history` 

DROP TABLE IF EXISTS `user_packages_history`; 

CREATE TABLE `user_packages_history` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `package_assign_id` int(11) DEFAULT NULL,
  `user_id` int(11) NOT NULL,
  `package_id` int(11) NOT NULL,
  `user_stb_smart_id` int(11) DEFAULT NULL,
  `status` tinyint(1) DEFAULT NULL,
  `charge_type` tinyint(1) DEFAULT '0',
  `package_start_date` datetime DEFAULT NULL,
  `package_expire_date` datetime DEFAULT NULL,
  `no_of_days` int(11) DEFAULT NULL,
  `user_package_type_id` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=18212 DEFAULT CHARSET=utf8;

-- Structure for Table `user_types` 

DROP TABLE IF EXISTS `user_types`; 

CREATE TABLE `user_types` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `user_type` varchar(10) DEFAULT NULL,
  `is_active` tinyint(1) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=latin1 CHECKSUM=1 DELAY_KEY_WRITE=1 ROW_FORMAT=DYNAMIC;

-- Structure for Table `users` 

DROP TABLE IF EXISTS `users`; 

CREATE TABLE `users` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `profile_id` int(11) NOT NULL,
  `username` varchar(40) DEFAULT NULL,
  `email` varchar(300) DEFAULT NULL,
  `password` varchar(40) DEFAULT NULL,
  `user_type` enum('MSO','LCO','Subscriber','Group') DEFAULT NULL,
  `role_id` int(11) NOT NULL,
  `user_status` tinyint(1) DEFAULT NULL,
  `is_remote_access_enabled` tinyint(1) DEFAULT '0',
  `is_first_loggedin` tinyint(1) DEFAULT '0',
  `is_iptv` tinyint(1) DEFAULT '0' COMMENT '0 = DVB , 1 = IPTV',
  `clientType` varchar(20) DEFAULT NULL,
  `macAddress` varchar(20) DEFAULT NULL,
  `imeiNumber` varchar(20) DEFAULT NULL,
  `operatorId` varchar(20) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `created_by` int(11) DEFAULT NULL,
  `token` varchar(40) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` int(11) DEFAULT NULL,
  `iptv_token` varchar(100) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fk_users_profiles1_idx` (`profile_id`),
  KEY `fk_users_roles1_idx` (`role_id`)
) ENGINE=InnoDB AUTO_INCREMENT=7427 DEFAULT CHARSET=utf8;

-- 
-- PROCEDURES 
-- 

DELIMITER $$

CREATE DEFINER=`root`@`%` PROCEDURE `GetRegions`()
BEGIN
	select id,name,region_l1_code, region_l2_code,region_l3_code,region_l4_code,hex_code 
	from
	(
		select a.region_l1_name name,a.id,a.region_l1_code,a.region_l2_code,a.region_l3_code,a.region_l4_code,a.hex_code 
		from region_level_1 a
		union
		select b.region_l2_name name,b.id,b.region_l1_code,b.region_l2_code,b.region_l3_code,b.region_l4_code,b.hex_code  
		from region_level_2 b
		union
		select d.region_l3_name name,d.id,d.region_l1_code,d.region_l2_code,d.region_l3_code,d.region_l4_code,d.hex_code 
		from region_level_3 d
		union
		select e.region_l4_name name,e.id,e.region_l1_code,e.region_l2_code,e.region_l3_code,e.region_l4_code,e.hex_code 
		from region_level_4 e
	) c
	order by region_l1_code,region_l2_code,region_l3_code,region_l4_code;
    END$$ 

DELIMITER ; 

-- 
-- Views 
-- 

-- Structure for View `view_collector_statements` 

DROP TABLE IF EXISTS `view_collector_statements`; 

CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `view_collector_statements` AS (select `billing_lco_collector`.`id` AS `id`,`billing_lco_collector`.`name` AS `name`,`GetUserPackageAssignTypeName`(`billing_subscriber_transactions`.`user_package_assign_type_id`) AS `description`,`billing_lco_collector`.`lco_id` AS `lco_id`,`billing_cash_transection`.`subscriber_transection_id` AS `subscriber_transection_id`,`billing_subscriber_transactions`.`credit` AS `credit`,`billing_subscriber_transactions`.`debit` AS `debit`,`billing_subscriber_transactions`.`balance` AS `balance`,`billing_subscriber_transactions`.`transaction_date` AS `transaction_date` from ((`billing_lco_collector` join `billing_cash_transection` on((`billing_lco_collector`.`id` = `billing_cash_transection`.`collector_id`))) join `billing_subscriber_transactions` on((`billing_cash_transection`.`subscriber_transection_id` = `billing_subscriber_transactions`.`id`))) where ((`billing_subscriber_transactions`.`demo` <> '1') and (`billing_subscriber_transactions`.`user_package_assign_type_id` in (4,7)))) union (select `billing_lco_collector`.`id` AS `id`,`billing_lco_collector`.`name` AS `name`,`GetUserPackageAssignTypeName`(`billing_subscriber_transactions`.`user_package_assign_type_id`) AS `description`,`billing_lco_collector`.`lco_id` AS `lco_id`,`billing_pos_transactions`.`subscriber_transaction_id` AS `subscriber_transaction_id`,`billing_subscriber_transactions`.`credit` AS `credit`,`billing_subscriber_transactions`.`debit` AS `debit`,`billing_subscriber_transactions`.`balance` AS `balance`,`billing_subscriber_transactions`.`transaction_date` AS `transaction_date` from ((`billing_lco_collector` join `billing_pos_transactions` on((`billing_lco_collector`.`id` = `billing_pos_transactions`.`collector_id`))) join `billing_subscriber_transactions` on((`billing_pos_transactions`.`subscriber_transaction_id` = `billing_subscriber_transactions`.`id`))) where ((`billing_subscriber_transactions`.`demo` <> '1') and (`billing_subscriber_transactions`.`user_package_assign_type_id` in (4,7))));

-- Structure for View `sub_menus` 

DROP TABLE IF EXISTS `sub_menus`; 

CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `sub_menus` AS (select `m2`.`id` AS `sub_menu_id`,`m2`.`menu_type` AS `sub_menu_type`,`m2`.`menu_name` AS `sub_menu`,`m2`.`route` AS `route`,`m2`.`display_order` AS `m2_display`,`m2`.`parent` AS `parent`,`m2`.`visible` AS `visible` from `plaas_menus` `m2` where ((`m2`.`parent` <> 0) and (`m2`.`visible` = 1)) order by `m2`.`display_order`);

-- Structure for View `main_menus` 

DROP TABLE IF EXISTS `main_menus`; 

CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `main_menus` AS (select `m1`.`id` AS `main_menu_id`,`m1`.`menu_type` AS `main_menu_type`,`m1`.`menu_name` AS `main_menu`,`m1`.`display_order` AS `display_order`,`m1`.`visible` AS `visible`,`m1`.`route` AS `route` from `plaas_menus` `m1` where ((`m1`.`parent` = 0) and (`m1`.`visible` = 1)) order by `m1`.`display_order`);

-- Structure for View `getmenus` 

DROP TABLE IF EXISTS `getmenus`; 

CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `getmenus` AS (select `main_menus`.`main_menu_id` AS `main_menu_id`,`main_menus`.`main_menu_type` AS `main_menu_type`,`main_menus`.`main_menu` AS `main_menu`,`main_menus`.`display_order` AS `display_order`,`main_menus`.`route` AS `main_menu_route`,`sub_menus`.`sub_menu_id` AS `sub_menu_id`,`sub_menus`.`sub_menu_type` AS `sub_menu_type`,`sub_menus`.`sub_menu` AS `sub_menu`,`sub_menus`.`route` AS `route`,`sub_menus`.`m2_display` AS `m2_display`,`sub_menus`.`parent` AS `parent`,`main_menus`.`visible` AS `main_menu_visible`,`sub_menus`.`visible` AS `sub_menu_visible` from (`main_menus` left join `sub_menus` on((`main_menus`.`main_menu_id` = `sub_menus`.`parent`))));

-- 
-- Triggers 
-- 

DELIMITER $$

CREATE DEFINER=`root`@`localhost` TRIGGER `GetPairingID_copy` BEFORE INSERT ON `ownership_transfers` FOR EACH ROW BEGIN
	begin
	  SET NEW.pairing_id = 1000000+GetAutoID('subscriber_stb_smartcards');
	end;
    END$$ 

CREATE DEFINER=`root`@`localhost` TRIGGER `gen_region_level_1_codeTr` BEFORE INSERT ON `region_level_1` 
    FOR EACH ROW BEGIN	
/*-- Update nex_corporate_client Activation Flag */
  begin
  SET NEW.region_l1_code = NEW.id;
  end;
END$$ 

CREATE DEFINER=`root`@`localhost` TRIGGER `gen_region_level_2_codeTr` BEFORE INSERT ON `region_level_2` 
    FOR EACH ROW BEGIN	
/*-- Update nex_corporate_client Activation Flag */
  begin
  SET NEW.region_l2_code = NEW.id;
  end;
END$$ 

CREATE DEFINER=`root`@`localhost` TRIGGER `gen_region_level_3_codeTr` BEFORE INSERT ON `region_level_3` 
    FOR EACH ROW BEGIN	
/*-- Update nex_corporate_client Activation Flag */
  begin
  SET NEW.region_l3_code = NEW.id;
  end;
END$$ 

CREATE DEFINER=`root`@`localhost` TRIGGER `gen_region_level_4_codeTr` BEFORE INSERT ON `region_level_4` 
    FOR EACH ROW BEGIN	
/*-- Update nex_corporate_client Activation Flag */
  begin
  SET NEW.region_l4_code = NEW.id;
  end;
END$$ 

CREATE DEFINER=`root`@`localhost` TRIGGER `set_card_serial_padding` BEFORE INSERT ON `scratch_card_detail` FOR EACH ROW BEGIN
	DECLARE temp VARCHAR(8);
	
	SET NEW.serial_no = LPAD(NEW.id,8,'0');
    END$$ 

CREATE DEFINER=`root`@`localhost` TRIGGER `gen_batch_number_Tr` BEFORE INSERT ON `scratch_card_info` FOR EACH ROW BEGIN	
/*-- Update nex_corporate_client Activation Flag */
  begin
  /*SET NEW.batch_no = concat(DATE_FORMAT(now(),'%Y%m%d'),cast(lpad(NEW.id,4,0)as signed integer));*/
  SET NEW.batch_no = cast(concat(DATE_FORMAT(now(),'%Y%m%d'),lpad(NEW.id,4,0))as signed integer);
  
  end;
END$$ 

CREATE DEFINER=`root`@`localhost` TRIGGER `GetPairingID` BEFORE INSERT ON `subscriber_stb_smartcards` FOR EACH ROW BEGIN
	begin
	  SET NEW.pairing_id = 1000000+GetAutoID('subscriber_stb_smartcards');
	end;
    END$$ 

CREATE DEFINER=`root`@`localhost` TRIGGER `user_packages_insTr` AFTER INSERT ON `user_packages` FOR EACH ROW BEGIN	
	/*-- Update client due summary */	
	  If (NEW.id>0) then				
		  Begin
		  insert into user_packages_history(package_assign_id,user_id,package_id,user_stb_smart_id,status,charge_type,package_start_date,package_expire_date,no_of_days,created_at,updated_at,created_by,user_package_type_id)
		  values (NEW.id,NEW.user_id,NEW.package_id,NEW.user_stb_smart_id,NEW.status,NEW.charge_type,NEW.package_start_date,NEW.package_expire_date,NEW.no_of_days,NEW.created_at,NEW.updated_at,NEW.created_by,NEW.user_package_type_id);
		  end;				
	  End If; 
END$$ 

CREATE DEFINER=`root`@`localhost` TRIGGER `user_packages_updTr` AFTER UPDATE ON `user_packages` FOR EACH ROW BEGIN	
	/*-- Update client due summary */		  
		  Begin
		  insert into user_packages_history(package_assign_id,user_id,package_id,user_stb_smart_id,status,charge_type,package_start_date,package_expire_date,no_of_days,created_at,updated_at,created_by,user_package_type_id)
		  values (OLD.id,OLD.user_id,OLD.package_id,OLD.user_stb_smart_id,OLD.status,NEW.charge_type,NEW.package_start_date,NEW.package_expire_date,NEW.no_of_days,OLD.created_at,OLD.updated_at,OLD.created_by,NEW.user_package_type_id);
		  end;				
	  
END$$ 

DELIMITER ; 

